@@ -9,15 +9,16 @@
 #     LICENSE file in the root directory of this source tree.
 #######################################################################################################################
 
+from scqubits.core.discretization import Grid1d
+from scqubits.core.flux_qubit import FluxQubit
+
 # core
 from scqubits.core.fluxonium import Fluxonium
+from scqubits.core.harmonic_osc import Oscillator
+from scqubits.core.hilbert_space import HilbertSpace
 from scqubits.core.transmon import Transmon
 from scqubits.core.zeropi import ZeroPi
 from scqubits.core.zeropi_full import FullZeroPi
-from scqubits.core.flux_qubit import FluxQubit
-from scqubits.core.harmonic_osc import Oscillator
-from scqubits.core.hilbert_space import HilbertSpace
-from scqubits.core.discretization import Grid1d
 
 # utils
 from scqubits.utils.constants import FileType
@@ -25,26 +26,3 @@ from scqubits.utils.spectrum_utils import get_matrixelement_table
 
 # version
 from scqubits.version import version as __version__
-
-
-# setup and teardown for nosetests
-def setup_package():
-    import matplotlib
-    import os
-    from scqubits.utils.constants import TEMPDIR
-
-    try:
-        __IPYTHON__
-    except:
-        matplotlib.pyplot.switch_backend('agg')   # do not actually show graphics in nosetests
-
-    if not os.path.exists(TEMPDIR):
-        try:
-            os.mkdir(TEMPDIR)
-        except OSError:
-            raise RuntimeError('Error creating temporary data directory ' + TEMPDIR)
-
-def teardown_package():
-    import shutil
-    from scqubits.utils.constants import TEMPDIR
-    shutil.rmtree(TEMPDIR)
